
.. _`Warnings`:

Warnings
--------

.. automodule:: pywbem._warnings

.. autoclass:: pywbem.Warning
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.ToleratedServerIssueWarning
    :members:
    :autosummary:
    :autosummary-inherited-members:
